@@ -74,6 +74,7 @@ class PACKAGEKITQT_LIBRARY Transaction : public QObject
     Q_PROPERTY(uint duration READ duration)
     Q_PROPERTY(QString data READ data)
     Q_PROPERTY(uint uid READ uid NOTIFY uidChanged)
+    Q_PROPERTY(QString senderName READ senderName NOTIFY senderNameChanged)
     Q_PROPERTY(QString cmdline READ cmdline)
 public:
     /**
@@ -612,6 +613,13 @@ public:
      */
     uint uid() const;
 
+    /**
+     * Returns the D-Bus name of the calling process
+     * \return the unique D-Bus name of the calling process
+     * \note This function only returns a usable value for ongoing transactions
+     */
+    QString senderName() const;
+
     /**
      * Returns the command line for the calling process
      * \return a string of the command line for the calling process
@@ -697,6 +705,8 @@ Q_SIGNALS:
 
     void uidChanged();
 
+    void senderNameChanged();
+
     /**
      * \brief Sends a category
      *
@@ -861,7 +871,7 @@ private:
     Q_PRIVATE_SLOT(d_func(), void ItemProgress(const QString &itemID, uint status, uint percentage))
     Q_PRIVATE_SLOT(d_func(), void RepoSignatureRequired(const QString &pid, const QString &repoName, const QString &keyUrl, const QString &keyUserid, const QString &keyId, const QString &keyFingerprint, const QString &keyTimestamp, uint type))
     Q_PRIVATE_SLOT(d_func(), void requireRestart(uint type, const QString &pid))
-    Q_PRIVATE_SLOT(d_func(), void transaction(const QDBusObjectPath &oldTid, const QString &timespec, bool succeeded, uint role, uint duration, const QString &data, uint uid, const QString &cmdline))
+    Q_PRIVATE_SLOT(d_func(), void transaction(const QDBusObjectPath &oldTid, const QString &timespec, bool succeeded, uint role, uint duration, const QString &data, uint uid, const QString &senderName, const QString &cmdline))
     Q_PRIVATE_SLOT(d_func(), void UpdateDetail(const QString &package_id, const QStringList &updates, const QStringList &obsoletes, const QStringList &vendor_urls, const QStringList &bugzilla_urls, const QStringList &cve_urls, uint restart, const QString &update_text, const QString &changelog, uint state, const QString &issued, const QString &updated))
     Q_PRIVATE_SLOT(d_func(), void UpdateDetails(const QList<PackageKit::PkDetail> &dets))
     Q_PRIVATE_SLOT(d_func(), void destroy())
